==> lpint_1.0.tar.gz: lpint/man/lpint-package.Rd <==
\name{lpint-package}
\alias{lpint-package}
% \alias{lpint}
\docType{package}
\title{
Local polynomail estimators of the intensity function of a counting
process and its derivatives
% ~~ package title ~~
}
\description{
Estimates the intensity function or its derivative of a give a given
order using the local polynomial method with automatic bandwidth
selection using a crude rule of thumb plug-in approach.
% ~~ A concise (1-5 lines) description of the package ~~
}
\details{
\tabular{ll}{
Package: \tab lpint\cr
Type: \tab Package\cr
Version: \tab 1.0\cr
Date: \tab 2012-09-21\cr
License: \tab GPL (>=2.0)\cr
LazyLoad: \tab yes\cr
}
% ~~ An overview of how to use the package, including the most important ~~
% ~~ functions ~~
}
\author{
Feng Chen <feng.chen@unsw.edu.au.>

Maintainer: Feng Chen <feng.chen@unsw.edu.au>
% ~~ The author and/or maintainer of the package ~~
}
\references{
  Chen, F. (2011) Maximum local partial likelihood estimators for the
  counting process intensity function and its derivatives. Statistica
  Sinica 21(1): 107
  -128. http://www3.stat.sinica.edu.tw/statistica/j21n1/J21N14/J21N14.html 

  Chen, F., Yip, P.S.F., & Lam, K.F. (2011) On the Local Polynomial
  Estimators of the Counting Process Intensity Function and its
  Derivatives. Scandinavian Journal of Statistics 38(4): 631 -
  649. http://dx.doi.org/10.1111/j.1467-9469.2011.00733.x

  Chen, F., Higgins, R.M., Yip, P.S.F. & Lam, K.F. (2008) Nonparametric
  estimation of multiplicative counting process intensity functions with
  an application to the Beijing SARS epidemic, Communications in
  Statistics - Theory and Methods 37: 294 -
  306. http://www.tandfonline.com/doi/abs/10.1080/03610920701649035  

  Chen, F., Higgins, R.M., Yip, P.S.F. & Lam, K.F. (2008) Local polynomial
  estimation of Poisson intensities in the presence of reporting
  delays, Journal of the Royal Statistical Society Series C (Applied
  Statistics) 57(4): 447 -
  459. http://onlinelibrary.wiley.com/doi/10.1111/j.1467-9876.2008.00624.x/full 
% ~~ Literature or other references for background information ~~
}
% ~~ Optionally other standard keywords, one per line, from file KEYWORDS in ~~
% ~~ the R documentation directory ~~
\keyword{ package }
\seealso{
% ~~ Optional links to other man pages, e.g. ~~
% ~~ \code{\link[<pkg>:<pkg>-package]{<pkg>}} ~~
}
\examples{
% ~~ simple examples of the most important functions ~~
}

==> lpint_2.0.tar.gz: lpint/man/lpint-package.Rd <==
\name{lpint-package}
\alias{lpint-package}
% \alias{lpint}
\docType{package}
\title{
Local polynomail estimators of the intensity function of a counting
process and its derivatives
% ~~ package title ~~
}
\description{
Estimates the intensity function or its derivative of a give a given
order using the local polynomial method with automatic bandwidth
selection using a crude rule of thumb plug-in approach.
% ~~ A concise (1-5 lines) description of the package ~~
}
\details{
\tabular{ll}{
Package: \tab lpint\cr
Type: \tab Package\cr
Version: \tab 1.0\cr
Date: \tab 2012-09-21\cr
License: \tab GPL (>=2.0)\cr
LazyLoad: \tab yes\cr
}
% ~~ An overview of how to use the package, including the most important ~~
% ~~ functions ~~
}
\author{
Feng Chen <feng.chen@unsw.edu.au>
Maintainer: Feng Chen <feng.chen@unsw.edu.au>
% ~~ The author and/or maintainer of the package ~~
}
\references{
  Chen, F. (2011) Maximum local partial likelihood estimators for the
  counting process intensity function and its derivatives. Statistica
  Sinica 21(1): 107
  -128. http://www3.stat.sinica.edu.tw/statistica/j21n1/J21N14/J21N14.html 

  Chen, F., Yip, P.S.F., & Lam, K.F. (2011) On the Local Polynomial
  Estimators of the Counting Process Intensity Function and its
  Derivatives. Scandinavian Journal of Statistics 38(4): 631 -
  649. http://dx.doi.org/10.1111/j.1467-9469.2011.00733.x

  Chen, F., Higgins, R.M., Yip, P.S.F. & Lam, K.F. (2008) Nonparametric
  estimation of multiplicative counting process intensity functions with
  an application to the Beijing SARS epidemic, Communications in
  Statistics - Theory and Methods 37: 294 -
  306. http://www.tandfonline.com/doi/abs/10.1080/03610920701649035  

  Chen, F., Higgins, R.M., Yip, P.S.F. & Lam, K.F. (2008) Local polynomial
  estimation of Poisson intensities in the presence of reporting
  delays, Journal of the Royal Statistical Society Series C (Applied
  Statistics) 57(4): 447 -
  459. http://onlinelibrary.wiley.com/doi/10.1111/j.1467-9876.2008.00624.x/full 
% ~~ Literature or other references for background information ~~
}
% ~~ Optionally other standard keywords, one per line, from file KEYWORDS in ~~
% ~~ the R documentation directory ~~
\keyword{ package }
% \seealso{
% % ~~ Optional links to other man pages, e.g. ~~
% % ~~ \code{\link[<pkg>:<pkg>-package]{<pkg>}} ~~
% }
% \examples{
% % ~~ simple examples of the most important functions ~~
% }
